@@ -927,7 +927,7 @@ KURL AptProtocol::buildURL( const KURL& query ) const
 *
 */
 
-extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
+extern "C" { TDE_EXPORT int kdemain(int argc, char **argv); }
 
 extern "C" {
   int kdemain( int argc, char **argv ) {
